@@ -8,38 +8,55 @@
  */
 
 package org.gnu.gnome;
+
+import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
+
 /**
- * This is a base class that acts as a parent for both GnomeCanvasRect
- * and GnomeCanvasEllipse. This base class includes information
- * pertaining to colors and sizes, but the two decendents contain the
- * drawing details.
+ * This is a base class that acts as a parent for both GnomeCanvasRect and
+ * GnomeCanvasEllipse. This base class includes information pertaining to colors
+ * and sizes, but the two decendents contain the drawing details.
  */
 public class CanvasRE extends CanvasShape {
 	protected static String ARG_NAME_X1 = "x1";
+
 	protected static String ARG_NAME_Y1 = "y1";
+
 	protected static String ARG_NAME_X2 = "x2";
+
 	protected static String ARG_NAME_Y2 = "y2";
+
 	protected static String ARG_NAME_FILL_COLOR = "fill_color";
+
 	protected static String ARG_NAME_FILL_COLOR_GDK = "fill_color_gdk";
+
 	protected static String ARG_NAME_FILL_COLOR_RGBA = "fill_color_rgba";
+
 	protected static String ARG_NAME_OUTLINE_COLOR = "outline_color";
+
 	protected static String ARG_NAME_OUTLINE_COLOR_GDK = "outline_gdk_color";
+
 	protected static String ARG_NAME_OUTLINE_COLOR_RGBA = "outline_color_rgba";
+
 	protected static String ARG_NAME_FILL_STIPPLE = "fill_stipple";
+
 	protected static String ARG_NAME_OUTLINE_STIPPLE = "outline_stipple";
+
 	protected static String ARG_NAME_WIDTH_PIXELS = "width_pixels";
+
 	protected static String ARG_NAME_WIDTH_UNITS = "width_units";
 
 	protected CanvasRE(CanvasGroup group, int type) {
 		super(group, type);
 	}
-	
+
 	/**
 	 * Constructs an instance of CanvasRE from a native widget resource.
-	 * @param handle The handle to the native widget.
+	 * 
+	 * @param handle
+	 *            The handle to the native widget.
 	 */
-	CanvasRE(int handle) {
+	CanvasRE(Handle handle) {
 		super(handle);
 	}
 
@@ -50,38 +67,22 @@ public class CanvasRE extends CanvasShape {
 		return new Type(gnome_canvas_re_get_type());
 	}
 
-	/****************************************
-	 * BEGINNING OF GENERATED CODE
-	 ****************************************/
-	native static final protected void gnome_canvas_request_redraw(int canvas, int x1, int y1, int x2, int y2);
+	native static final protected void gnome_canvas_request_redraw(
+			Handle canvas, int x1, int y1, int x2, int y2);
 	native static final protected int gnome_canvas_re_get_type();
-	native static final protected int gnome_canvas_re_new_gdk_wpix(
-		int group,
-		int type,
-		double x1,
-		double y1,
-		double x2,
-		double y2,
-		int fill_color,
-		int outline_color,
-		int fill_stipple,
-		int outline_stipple,
-		int width_pixels);
-	native static final protected int gnome_canvas_re_new_gdk_wunit(
-		int group,
-		int type,
-		double x1,
-		double y1,
-		double x2,
-		double y2,
-		int fill_color,
-		int outline_color,
-		int fill_stipple,
-		int outline_stipple,
-		double width_units);
-	native static final protected int gnome_canvas_re_new_rgba_wpix(int group, int type, double x1, double y1, double x2, double y2, int fill_color, int outline_color, int width_pixels);
-	native static final protected int gnome_canvas_re_new_rgba_wunit(int group, int type, double x1, double y1, double x2, double y2, int fill_color, int outline_color, double width_units);
-	/****************************************
-	 * END OF GENERATED CODE
-	 ****************************************/
+	native static final protected Handle gnome_canvas_re_new_gdk_wpix(
+			Handle group, int type, double x1, double y1, double x2, double y2,
+			Handle fill_color, Handle outline_color, Handle fill_stipple,
+			Handle outline_stipple, int width_pixels);
+	native static final protected Handle gnome_canvas_re_new_gdk_wunit(
+			Handle group, int type, double x1, double y1, double x2, double y2,
+			Handle fill_color, Handle outline_color, Handle fill_stipple,
+			Handle outline_stipple, double width_units);
+	native static final protected Handle gnome_canvas_re_new_rgba_wpix(
+			Handle group, int type, double x1, double y1, double x2, double y2,
+			int fill_color, int outline_color, int width_pixels);
+	native static final protected Handle gnome_canvas_re_new_rgba_wunit(
+			Handle group, int type, double x1, double y1, double x2, double y2,
+			int fill_color, int outline_color, double width_units);
+
 }
